ObservabilityServiceClient

Struct ObservabilityServiceClient 

pub struct ObservabilityServiceClient<T> { /* private fields */ }
Observability service for monitoring Vector instances.

Implementations

Source

impl ObservabilityServiceClient<Channel>

pub async fn connect<D>(dst: D) -> Result<Self, Error>
where D: TryInto<Endpoint>, D::Error: Into<StdError>,

Attempt to create a new client by connecting to a given endpoint.

Source

impl<T> ObservabilityServiceClient<T>
where T: GrpcService<BoxBody>, T::Error: Into<StdError>, T::ResponseBody: Body<Data = Bytes> + Send + 'static, <T::ResponseBody as Body>::Error: Into<StdError> + Send,

pub fn new(inner: T) -> Self

pub fn with_origin(inner: T, origin: Uri) -> Self

pub fn with_interceptor<F>( inner: T, interceptor: F, ) -> ObservabilityServiceClient<InterceptedService<T, F>>
where F: Interceptor, T::ResponseBody: Default, T: Service<Request<BoxBody>, Response = Response<<T as GrpcService<BoxBody>>::ResponseBody>>, <T as Service<Request<BoxBody>>>::Error: Into<StdError> + Send + Sync,

pub fn send_compressed(self, encoding: CompressionEncoding) -> Self

Compress requests with the given encoding.

This requires the server to support it otherwise it might respond with an error.

pub fn accept_compressed(self, encoding: CompressionEncoding) -> Self

Enable decompressing responses.

pub fn max_decoding_message_size(self, limit: usize) -> Self

Limits the maximum size of a decoded message.

Default: 4MB

pub fn max_encoding_message_size(self, limit: usize) -> Self

Limits the maximum size of an encoded message.

Default: usize::MAX

pub async fn get_meta( &mut self, request: impl IntoRequest<GetMetaRequest>, ) -> Result<Response<GetMetaResponse>, Status>

Get metadata about the Vector instance (version, hostname)

pub async fn get_components( &mut self, request: impl IntoRequest<GetComponentsRequest>, ) -> Result<Response<GetComponentsResponse>, Status>

Get information about configured components (sources, transforms, sinks)

pub async fn get_allocation_tracing_status( &mut self, request: impl IntoRequest<GetAllocationTracingStatusRequest>, ) -> Result<Response<GetAllocationTracingStatusResponse>, Status>

Check whether allocation tracing is active on this instance

pub async fn stream_heartbeat( &mut self, request: impl IntoRequest<StreamHeartbeatRequest>, ) -> Result<Response<Streaming<StreamHeartbeatResponse>>, Status>

Stream periodic heartbeat timestamps

pub async fn stream_uptime( &mut self, request: impl IntoRequest<StreamUptimeRequest>, ) -> Result<Response<Streaming<StreamUptimeResponse>>, Status>

Stream uptime in seconds

pub async fn stream_component_allocated_bytes( &mut self, request: impl IntoRequest<StreamComponentAllocatedBytesRequest>, ) -> Result<Response<Streaming<StreamComponentAllocatedBytesResponse>>, Status>

Stream memory allocated per component

pub async fn stream_component_metrics( &mut self, request: impl IntoRequest<StreamComponentMetricsRequest>, ) -> Result<Response<Streaming<StreamComponentMetricsResponse>>, Status>

Stream per-component metrics (throughput or totals) for a chosen metric. Replaces the former 9 per-metric streaming RPCs with a single unified endpoint.

pub async fn stream_output_events( &mut self, request: impl IntoRequest<StreamOutputEventsRequest>, ) -> Result<Response<Streaming<StreamOutputEventsResponse>>, Status>

Stream events from components matching the specified patterns (replaces vector tap)