pub struct ObservabilityServiceClient<T> { /* private fields */ }Expand description
Observability service for monitoring Vector instances.
Implementations
Sourceimpl<T> ObservabilityServiceClient<T>where
T: GrpcService<BoxBody>,
T::Error: Into<StdError>,
T::ResponseBody: Body<Data = Bytes> + Send + 'static,
<T::ResponseBody as Body>::Error: Into<StdError> + Send,
impl<T> ObservabilityServiceClient<T>where
T: GrpcService<BoxBody>,
T::Error: Into<StdError>,
T::ResponseBody: Body<Data = Bytes> + Send + 'static,
<T::ResponseBody as Body>::Error: Into<StdError> + Send,
pub fn new(inner: T) -> Self
pub fn with_origin(inner: T, origin: Uri) -> Self
pub fn with_interceptor<F>(
inner: T,
interceptor: F,
) -> ObservabilityServiceClient<InterceptedService<T, F>>where
F: Interceptor,
T::ResponseBody: Default,
T: Service<Request<BoxBody>, Response = Response<<T as GrpcService<BoxBody>>::ResponseBody>>,
<T as Service<Request<BoxBody>>>::Error: Into<StdError> + Send + Sync,
Sourcepub fn send_compressed(self, encoding: CompressionEncoding) -> Self
pub fn send_compressed(self, encoding: CompressionEncoding) -> Self
Compress requests with the given encoding.
This requires the server to support it otherwise it might respond with an error.
Sourcepub fn accept_compressed(self, encoding: CompressionEncoding) -> Self
pub fn accept_compressed(self, encoding: CompressionEncoding) -> Self
Enable decompressing responses.
Sourcepub fn max_decoding_message_size(self, limit: usize) -> Self
pub fn max_decoding_message_size(self, limit: usize) -> Self
Limits the maximum size of a decoded message.
Default: 4MB
Sourcepub fn max_encoding_message_size(self, limit: usize) -> Self
pub fn max_encoding_message_size(self, limit: usize) -> Self
Limits the maximum size of an encoded message.
Default: usize::MAX
Sourcepub async fn get_meta(
&mut self,
request: impl IntoRequest<GetMetaRequest>,
) -> Result<Response<GetMetaResponse>, Status>
pub async fn get_meta( &mut self, request: impl IntoRequest<GetMetaRequest>, ) -> Result<Response<GetMetaResponse>, Status>
Get metadata about the Vector instance (version, hostname)
Sourcepub async fn get_components(
&mut self,
request: impl IntoRequest<GetComponentsRequest>,
) -> Result<Response<GetComponentsResponse>, Status>
pub async fn get_components( &mut self, request: impl IntoRequest<GetComponentsRequest>, ) -> Result<Response<GetComponentsResponse>, Status>
Get information about configured components (sources, transforms, sinks)
Sourcepub async fn get_allocation_tracing_status(
&mut self,
request: impl IntoRequest<GetAllocationTracingStatusRequest>,
) -> Result<Response<GetAllocationTracingStatusResponse>, Status>
pub async fn get_allocation_tracing_status( &mut self, request: impl IntoRequest<GetAllocationTracingStatusRequest>, ) -> Result<Response<GetAllocationTracingStatusResponse>, Status>
Check whether allocation tracing is active on this instance
Sourcepub async fn stream_heartbeat(
&mut self,
request: impl IntoRequest<StreamHeartbeatRequest>,
) -> Result<Response<Streaming<StreamHeartbeatResponse>>, Status>
pub async fn stream_heartbeat( &mut self, request: impl IntoRequest<StreamHeartbeatRequest>, ) -> Result<Response<Streaming<StreamHeartbeatResponse>>, Status>
Stream periodic heartbeat timestamps
Sourcepub async fn stream_uptime(
&mut self,
request: impl IntoRequest<StreamUptimeRequest>,
) -> Result<Response<Streaming<StreamUptimeResponse>>, Status>
pub async fn stream_uptime( &mut self, request: impl IntoRequest<StreamUptimeRequest>, ) -> Result<Response<Streaming<StreamUptimeResponse>>, Status>
Stream uptime in seconds
Sourcepub async fn stream_component_allocated_bytes(
&mut self,
request: impl IntoRequest<StreamComponentAllocatedBytesRequest>,
) -> Result<Response<Streaming<StreamComponentAllocatedBytesResponse>>, Status>
pub async fn stream_component_allocated_bytes( &mut self, request: impl IntoRequest<StreamComponentAllocatedBytesRequest>, ) -> Result<Response<Streaming<StreamComponentAllocatedBytesResponse>>, Status>
Stream memory allocated per component
Sourcepub async fn stream_component_metrics(
&mut self,
request: impl IntoRequest<StreamComponentMetricsRequest>,
) -> Result<Response<Streaming<StreamComponentMetricsResponse>>, Status>
pub async fn stream_component_metrics( &mut self, request: impl IntoRequest<StreamComponentMetricsRequest>, ) -> Result<Response<Streaming<StreamComponentMetricsResponse>>, Status>
Stream per-component metrics (throughput or totals) for a chosen metric. Replaces the former 9 per-metric streaming RPCs with a single unified endpoint.
Sourcepub async fn stream_output_events(
&mut self,
request: impl IntoRequest<StreamOutputEventsRequest>,
) -> Result<Response<Streaming<StreamOutputEventsResponse>>, Status>
pub async fn stream_output_events( &mut self, request: impl IntoRequest<StreamOutputEventsRequest>, ) -> Result<Response<Streaming<StreamOutputEventsResponse>>, Status>
Stream events from components matching the specified patterns (replaces vector tap)